# asyncio.loop logs some things we might need to see.
import logging
logging.basicConfig()
del logging

# asyncio runs many error messages through reprlib,
# which defaults to fairly short strings,
# which is a major PITA.
from reprlib import aRepr
aRepr.maxstring = 9999
aRepr.maxother = 9999
aRepr.maxlong = 9999
del aRepr



import asyncio


class TestSync:
    def test_explicit_mainloop(self):
        async def foo():
            return "bar"

        async def bar():
            return "baz"

        loop = asyncio.new_event_loop()
        res = loop.run_until_complete(foo())
        assert res == "bar"
        res = loop.run_until_complete(bar())
        assert res == "baz"
        loop.close()
